@@ -195,7 +195,6 @@ bool copyselectedtiles();
 void clearselectedmaptiles();
 void pasteselectedtiles(int movex, int movey);
 void getcenterselection(int * x, int * y);
-void takescreenshot();
 
 bool viewblocks = true;
 bool view_only_layer = false;
@@ -2730,7 +2729,7 @@ int save_as()
 	if(dialog("Save As", "Enter name:", fileName, 64))
 	{
 		save_map(convertPath(strcat(strcat(mapLocation, fileName),".map")));
-		maplist.add(strcat(fileName, ".map"));
+		maplist.add(convertPathC(strcat(fileName, ".map")));
 		maplist.find(fileName);
 		loadcurrentmap();
 	}
@@ -3125,7 +3124,7 @@ int newmap()
 		g_map.clearPlatforms();
 		g_map.eyecandyID = 0;
 		g_map.saveMap(convertPath(strcat(strcat(mapLocation, fileName),".map")));
-		maplist.add(strcat(fileName, ".map"));
+		maplist.add(convertPathC(strcat(fileName, ".map")));
 		maplist.find(fileName);
 		loadcurrentmap();
 	}
