@@ -533,17 +533,12 @@ int main(int argc, char *argv[])
 {
 
 	system("/usr/bin/gconftool-2 -g /apps/osso/inputmethod/int_kb_layout > /home/user/int_kb_layout");
-
  	FILE *archivo;
 	char caracteres[100];
 	int c;
  	archivo = fopen("/home/user/int_kb_layout","r");
 	do { c = fscanf(archivo, "%s", caracteres); }
     while (c != EOF); 
-
- 	//while (feof(archivo) == 0) { fgets(caracteres,100,archivo); }
-
-	printf("\nEl contenido del archivo de prueba es -%s-\n\n",caracteres);
 	fclose(archivo);
 	if (caracteres!="us") system("/usr/bin/gconftool-2 -s /apps/osso/inputmethod/int_kb_layout us -t string");
 
